/*
 * AutoDAO - Generic DAO on steroids implementation for Java.
 *
 * Copyright 2008-2012  Marat Radchenko <slonopotamus@users.sourceforge.net>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sf.autodao;

import java.lang.annotation.Documented;
import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

/**
 * Put this annotation on generic dao method argument that should act as query limit.
 * <p/>
 * See <a href="http://autodao.sourceforge.net/guide.html#Paging_results">Paging results</a> for usage.
 * <p/>
 * Parameter must be of type <code>int</code> or {@link Integer}. If parameter is of type {@link Integer} and
 * <code>null</code> is passed then no limit is assumed. Single parameter can have both {@link Limit} and {@link Offset}
 * but this is unlikely to be useful. Parameters marked with {@link Limit} won't be passed to underlying ORM as query
 * parameters. This annotation can only be used in methods that return collection and only on one parameter.
 * @see Offset
 * @since AutoDAO 0.1
 */
@Documented
@Retention(RetentionPolicy.RUNTIME)
@Target(ElementType.PARAMETER)
public @interface Limit {

}
