/*
 * AutoDAO - Generic DAO on steroids implementation for Java.
 *
 * Copyright 2008-2012  Marat Radchenko <slonopotamus@users.sourceforge.net>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sf.autodao;

import java.lang.annotation.Documented;
import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

import org.jetbrains.annotations.NotNull;

/**
 * Use this annotation on finder method parameters if you want to use named parameters in queries.
 * <p/>
 * See <a href="http://autodao.sourceforge.net/guide.html#Named_parameters">Named parameters</a> for usage.
 * <p/>
 * It isn't valid to mix named and non-named (indexed) parameters on the same query method. If you're using {@link
 * Named} with {@link Limit} or {@link Offset}, then normal requirements for them are applied. It is a error to put
 * {@link Named} on the same parameter as {@link Limit} or {@link Offset}. <p/> It is a error to use several {@link
 * Named} with same value on single finder method.
 * @since AutoDAO 0.1
 */
@Documented
@Retention(RetentionPolicy.RUNTIME)
@Target(ElementType.PARAMETER)
public @interface Named {
  /** @return parameter name */
  @NotNull String value();
}
